@@ -1,7 +1,7 @@
 import sys
 import click
 import jmespath
-from cloudscale import Cloudscale, CloudscaleApiException, CloudscaleException
+from cloudscale import Cloudscale
 from ..util import to_table, to_pretty_json, tags_to_dict
 
 if sys.stdout.isatty():
@@ -23,7 +23,7 @@ class CloudscaleCommand:
                 profile=profile,
                 debug=debug
             )
-        except CloudscaleException as e:
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
 
@@ -43,7 +43,7 @@ class CloudscaleCommand:
                 response = [response]
             return to_table(response, self.headers)
 
-    def cmd_list(self, filter_tag=None, filter_json=None, action=None, delete=False):
+    def cmd_list(self, filter_tag=None, filter_json=None, action=None, delete=False, force=False):
         if action and delete:
             click.echo("Error: --action and --delete are mutually exclusive", err=True)
             sys.exit(1)
@@ -56,28 +56,31 @@ class CloudscaleCommand:
                 except Exception as e:
                     click.echo(f"filter_json error: {e}", err=True)
                     sys.exit(1)
-            click.echo(self._format_output(response))
-            if delete:
-                click.confirm(f"Do you want to delete?", abort=True)
-                for r in response:
-                    if 'href' not in r:
-                        click.echo("No href found, could not delete.", err=True)
-                        sys.exit(1)
-                    uuid = r['href'].split('/')[-1]
-                    self.cmd_delete(uuid=uuid, force=True, skip_query=True)
-            elif action:
-                click.confirm(f"Do you want to {action}?", abort=True)
-                for r in response:
-                    if 'href' not in r:
-                        click.echo(f"No href found, could not {action}.", err=True)
-                        sys.exit(1)
-                    uuid = r['href'].split('/')[-1]
-                    with Spinner(text=f"{action.capitalize()} {uuid}"):
-                        getattr(self.get_client_resource(), action)(uuid)
-                with Spinner(text="Querying"):
-                    response = self.get_client_resource().get_all(filter_tag)
+            if response:
                 click.echo(self._format_output(response))
-        except CloudscaleApiException as e:
+                if delete:
+                    if not force:
+                        click.confirm(f"Do you want to delete?", abort=True)
+                    for r in response:
+                        if 'href' not in r:
+                            click.echo("No href found, could not delete.", err=True)
+                            sys.exit(1)
+                        uuid = r['href'].split('/')[-1]
+                        self.cmd_delete(uuid=uuid, force=True, skip_query=True)
+                elif action:
+                    if not force:
+                        click.confirm(f"Do you want to {action}?", abort=True)
+                    for r in response:
+                        if 'href' not in r:
+                            click.echo(f"No href found, could not {action}.", err=True)
+                            sys.exit(1)
+                        uuid = r['href'].split('/')[-1]
+                        with Spinner(text=f"{action.capitalize()} {uuid}"):
+                            getattr(self.get_client_resource(), action)(uuid)
+                    with Spinner(text="Querying"):
+                        response = self.get_client_resource().get_all(filter_tag)
+                    click.echo(self._format_output(response))
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
 
@@ -86,7 +89,7 @@ class CloudscaleCommand:
             with Spinner(text=f"Querying {uuid}"):
                 response = self.get_client_resource().get_by_uuid(uuid)
             click.echo(self._format_output(response))
-        except CloudscaleApiException as e:
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
 
@@ -104,7 +107,7 @@ class CloudscaleCommand:
                 click.echo(self._format_output(response))
             else:
                 return response
-        except CloudscaleApiException as e:
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
 
@@ -133,7 +136,7 @@ class CloudscaleCommand:
                 )
                 response = self.get_client_resource().get_by_uuid(uuid=uuid)
             click.echo(self._format_output(response))
-        except CloudscaleApiException as e:
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
 
@@ -148,7 +151,7 @@ class CloudscaleCommand:
             with Spinner(text=f"Deleting {uuid}"):
                 self.get_client_resource().delete(uuid)
             click.echo(f"{uuid} deleted!")
-        except CloudscaleApiException as e:
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
 
@@ -160,6 +163,6 @@ class CloudscaleCommand:
             with Spinner(text=f"Querying {uuid}"):
                 response = self.get_client_resource().get_by_uuid(uuid)
             click.echo(self._format_output(response))
-        except CloudscaleApiException as e:
+        except Exception as e:
             click.echo(e, err=True)
             sys.exit(1)
