@@ -17,13 +17,15 @@ def floating_ip(ctx):
 @click.option('--filter-tag')
 @click.option('--filter-json')
 @click.option('--delete', is_flag=True)
+@click.option('--force', is_flag=True)
 @floating_ip.command("list")
 @click.pass_obj
-def cmd_list(cloudscale, filter_tag, filter_json, delete):
+def cmd_list(cloudscale, filter_tag, filter_json, delete, force):
     cloudscale.cmd_list(
         filter_tag=filter_tag,
         filter_json=filter_json,
         delete=delete,
+        force=force,
     )
 
 @click.argument('network-id', required=True)
